function [t, Y] = Euler(dYdt,t0,Y0,DeltaT,tf)
%
% Written:  February 21, 2003
% Revised:  March 17, 2004
%
% Purpose: Given a system of ordinary differential equations, 
% initial t, x and y, values, delta t and final time value, 
% the Euler function will approximate the solution to the 
% inital value problem over the interval [t0,tf] using Euler's 
% Method. 
%
% Usage: [t,y] = Euler2d('dYdt',t0,Y0,DeltaT,tf)
%
% 'dYdt' is the name of a vector-valued function, F(t,y), that
% gives the differential equation to be solved with initial
% value (t0,Y0).  If this is defined as an m-file, you must use
% the single quotes when passing this to the function Euler.
%
% DeltaT indicates the time step to be used, and tf is the
% final solution time, i.e. Euler's Method is used to approximate
% the solution to the ODE given by 
%     dY/dt = F(t,Y) with Y(t0) = Y0 (an nx1 vector)  for t0 <= t <= tf
% using step size of DeltaT.
%

% Define n, the number of iterations of Euler' Method
n = round((tf - t0)/DeltaT);

% Create the solution "vectors", t and Y, and input their initial
% values ... Note that Y will be 2 x n, where each column corresponds
% to a different value of time, and each row corresponds to a different
% variable.  We use the first row of Y for our x(t) values and the second
% row of Y for our y(t) values.
t = [];
Y = [];
t(1) = t0;

% If Y0 is a row vector, change it to a column vector
if size(Y0,1) == 1
    Y0 = Y0';
end;

Y(:,1) = Y0;  % set the first column of the matrix Y to contain the
              % initial values

for k = 1:n
   t(k+1) = t(k) + DeltaT;
   Y(:,k+1) = Y(:,k) + feval(dYdt,t(k),Y(:,k)).*DeltaT;
end;


